/*  Creator: make/0

    Purpose: Provide index for autoload
*/

index(aggregate(?,^,-), aggregate, aggregate).
index(aggregate(?,?,^,-), aggregate, aggregate).
index(aggregate_all(?,0,-), aggregate, aggregate).
index(aggregate_all(?,?,0,-), aggregate, aggregate).
index(foldall(2,0,+,-), aggregate, aggregate).
index(foreach(0,0), aggregate, aggregate).
index(free_variables(?,?,?,?), aggregate, aggregate).
index(ansi_format(?,?,?), ansi_term, ansi_term).
index(ansi_get_color(?,?), ansi_term, ansi_term).
index(ansi_hyperlink(?,?), ansi_term, ansi_term).
index(ansi_hyperlink(?,?,?), ansi_term, ansi_term).
index(include(1,+,-), apply, apply).
index(exclude(1,+,-), apply, apply).
index(partition(1,+,-,-), apply, apply).
index(partition(2,+,-,-,-), apply, apply).
index(maplist(1,?), apply, apply).
index(maplist(2,?,?), apply, apply).
index(maplist(3,?,?,?), apply, apply).
index(maplist(4,?,?,?,?), apply, apply).
index(convlist(2,+,-), apply, apply).
index(foldl(3,+,+,-), apply, apply).
index(foldl(4,+,+,+,-), apply, apply).
index(foldl(5,+,+,+,+,-), apply, apply).
index(foldl(6,+,+,+,+,+,-), apply, apply).
index(scanl(3,+,+,-), apply, apply).
index(scanl(4,+,+,+,-), apply, apply).
index(scanl(5,+,+,+,+,-), apply, apply).
index(scanl(6,+,+,+,+,+,-), apply, apply).
index(expand_phrase(?,?), apply_macros, apply_macros).
index(expand_phrase(?,?,?,?), apply_macros, apply_macros).
index(apply_macros_sentinel, apply_macros, apply_macros).
index(arithmetic_function(:), arithmetic, arithmetic).
index(arithmetic_expression_value(:,-), arithmetic, arithmetic).
index(empty_assoc(?), assoc, assoc).
index(is_assoc(?), assoc, assoc).
index(assoc_to_list(?,?), assoc, assoc).
index(assoc_to_keys(?,?), assoc, assoc).
index(assoc_to_values(?,?), assoc, assoc).
index(gen_assoc(?,?,?), assoc, assoc).
index(get_assoc(?,?,?), assoc, assoc).
index(get_assoc(?,?,?,?,?), assoc, assoc).
index(list_to_assoc(?,?), assoc, assoc).
index(map_assoc(1,?), assoc, assoc).
index(map_assoc(2,?,?), assoc, assoc).
index(max_assoc(?,?,?), assoc, assoc).
index(min_assoc(?,?,?), assoc, assoc).
index(ord_list_to_assoc(?,?), assoc, assoc).
index(put_assoc(?,?,?,?), assoc, assoc).
index(del_assoc(?,?,?,?), assoc, assoc).
index(del_min_assoc(?,?,?,?), assoc, assoc).
index(del_max_assoc(?,?,?,?), assoc, assoc).
index(restyle_identifier(?,?,?), atom, atom).
index(identifier_parts(?,?), atom, atom).
index(join_identifier_parts(?,?,?), atom, atom).
index('$arch'(?,?), backward_compatibility, backcomp).
index('$version'(?), backward_compatibility, backcomp).
index('$home'(?), backward_compatibility, backcomp).
index('$argv'(?), backward_compatibility, backcomp).
index('$set_prompt'(?), backward_compatibility, backcomp).
index('$strip_module'(?,?,?), backward_compatibility, backcomp).
index('$declare_module'(?,?,?), backward_compatibility, backcomp).
index('$module'(?,?), backward_compatibility, backcomp).
index(at_initialization(0), backward_compatibility, backcomp).
index(displayq(?), backward_compatibility, backcomp).
index(displayq(?,?), backward_compatibility, backcomp).
index(sformat(?,?), backward_compatibility, backcomp).
index(sformat(?,?,?), backward_compatibility, backcomp).
index(concat(?,?,?), backward_compatibility, backcomp).
index(concat_atom(?,?), backward_compatibility, backcomp).
index(concat_atom(?,?,?), backward_compatibility, backcomp).
index('$apropos_match'(?,?), backward_compatibility, backcomp).
index(read_clause(?), backward_compatibility, backcomp).
index(read_clause(?,?), backward_compatibility, backcomp).
index(read_variables(?,?), backward_compatibility, backcomp).
index(read_variables(?,?,?), backward_compatibility, backcomp).
index(read_pending_input(?,?,?), backward_compatibility, backcomp).
index(feature(?,?), backward_compatibility, backcomp).
index(set_feature(?,?), backward_compatibility, backcomp).
index(substring(?,?,?,?), backward_compatibility, backcomp).
index(string_to_list(?,?), backward_compatibility, backcomp).
index(string_to_atom(?,?), backward_compatibility, backcomp).
index(flush, backward_compatibility, backcomp).
index(write_ln(?), backward_compatibility, backcomp).
index(proper_list(?), backward_compatibility, backcomp).
index(free_variables(?,?), backward_compatibility, backcomp).
index(hash_term(?,?), backward_compatibility, backcomp).
index(checklist(1,+), backward_compatibility, backcomp).
index(sublist(1,+,?), backward_compatibility, backcomp).
index(sumlist(?,?), backward_compatibility, backcomp).
index(convert_time(?,?), backward_compatibility, backcomp).
index(convert_time(?,?,?,?,?,?,?,?), backward_compatibility, backcomp).
index('C'(?,?,?), backward_compatibility, backcomp).
index(current_thread(?,?), backward_compatibility, backcomp).
index(current_mutex(?,?,?), backward_compatibility, backcomp).
index(message_queue_size(?,?), backward_compatibility, backcomp).
index(lock_predicate(?,?), backward_compatibility, backcomp).
index(unlock_predicate(?,?), backward_compatibility, backcomp).
index(current_module(?,?), backward_compatibility, backcomp).
index(export_list(?,?), backward_compatibility, backcomp).
index(call_cleanup(0,?,0), backward_compatibility, backcomp).
index(setup_and_call_cleanup(0,0,0), backward_compatibility, backcomp).
index(setup_and_call_cleanup(0,0,?,0), backward_compatibility, backcomp).
index(merge(?,?,?), backward_compatibility, backcomp).
index(merge_set(?,?,?), backward_compatibility, backcomp).
index(index(:), backward_compatibility, backcomp).
index(hash(:), backward_compatibility, backcomp).
index(set_base_module(:), backward_compatibility, backcomp).
index(eval_license, backward_compatibility, backcomp).
index(trie_insert_new(?,?,?), backward_compatibility, backcomp).
index(thread_at_exit(0), backward_compatibility, backcomp).
index(read_history(?,?,?,?,?,?), backward_compatibility, backcomp).
index('$sig_atomic'(0), backward_compatibility, backcomp).
index(base32(?,?), base32, base32).
index(base32(?,?,?), base32, base32).
index(base64_encoded(?,?,?), base64, base64).
index(base64_encoded(?,?,?,?), base64, base64).
index(base64(?,?), base64, base64).
index(base64(?,?,?), base64, base64).
index(base64url(?,?), base64, base64).
index(base64url(?,?,?), base64, base64).
index(listen(+,+,0), broadcast, broadcast).
index(listen(+,0), broadcast, broadcast).
index(unlisten(?), broadcast, broadcast).
index(unlisten(?,?), broadcast, broadcast).
index(unlisten(+,+,0), broadcast, broadcast).
index(listening(?,?,?), broadcast, broadcast).
index(broadcast(?), broadcast, broadcast).
index(broadcast_request(?), broadcast, broadcast).
index(format_to_chars(?,?,?), charsio, charsio).
index(format_to_chars(?,?,?,?), charsio, charsio).
index(write_to_chars(?,?), charsio, charsio).
index(write_to_chars(?,?,?), charsio, charsio).
index(atom_to_chars(?,?), charsio, charsio).
index(atom_to_chars(?,?,?), charsio, charsio).
index(number_to_chars(?,?), charsio, charsio).
index(number_to_chars(?,?,?), charsio, charsio).
index(read_from_chars(?,?), charsio, charsio).
index(read_term_from_chars(?,?,?), charsio, charsio).
index(open_chars_stream(?,?), charsio, charsio).
index(with_output_to_chars(0,-), charsio, charsio).
index(with_output_to_chars(0,-,?), charsio, charsio).
index(with_output_to_chars(0,-,-,?), charsio, charsio).
index(check, check, check).
index(list_undefined, check, check).
index(list_undefined(?), check, check).
index(list_autoload, check, check).
index(list_redefined, check, check).
index(list_cross_module_calls, check, check).
index(list_cross_module_calls(?), check, check).
index(list_void_declarations, check, check).
index(list_trivial_fails, check, check).
index(list_trivial_fails(?), check, check).
index(list_format_errors, check, check).
index(list_format_errors(?), check, check).
index(list_strings, check, check).
index(list_strings(?), check, check).
index(list_rationals, check, check).
index(list_rationals(?), check, check).
index(check_installation, check_installation, check_installation).
index(check_installation(?), check_installation, check_installation).
index(check_config_files, check_installation, check_installation).
index(update_config_files, check_installation, check_installation).
index(test_installation, check_installation, check_installation).
index(test_installation(?), check_installation, check_installation).
index(format_to_codes(?,?,?), codesio, codesio).
index(format_to_codes(?,?,?,?), codesio, codesio).
index(write_to_codes(?,?), codesio, codesio).
index(write_to_codes(?,?,?), codesio, codesio).
index(write_term_to_codes(?,?,?), codesio, codesio).
index(write_term_to_codes(?,?,?,?), codesio, codesio).
index(read_from_codes(?,?), codesio, codesio).
index(read_term_from_codes(?,?,?), codesio, codesio).
index(open_codes_stream(?,?), codesio, codesio).
index(with_output_to_codes(0,-), codesio, codesio).
index(with_output_to_codes(0,-,?), codesio, codesio).
index(with_output_to_codes(0,-,-,?), codesio, codesio).
index(coinductive(?), coinduction, coinduction).
index(:(op,op(1150,fx,coinductive)), coinduction, coinduction).
index(csv(?,?,?), csv, csv).
index(csv(?,?,?,?), csv, csv).
index(csv_read_file(?,?), csv, csv).
index(csv_read_file(?,?,?), csv, csv).
index(csv_read_stream(?,?,?), csv, csv).
index(csv_read_file_row(?,?,?), csv, csv).
index(csv_read_row(?,?,?), csv, csv).
index(csv_options(?,?), csv, csv).
index(csv_write_file(?,?), csv, csv).
index(csv_write_file(?,?,?), csv, csv).
index(csv_write_stream(?,?,?), csv, csv).
index(is_alnum(?), ctypes, ctypes).
index(is_alpha(?), ctypes, ctypes).
index(is_ascii(?), ctypes, ctypes).
index(is_cntrl(?), ctypes, ctypes).
index(is_csym(?), ctypes, ctypes).
index(is_csymf(?), ctypes, ctypes).
index(is_digit(?), ctypes, ctypes).
index(is_digit(?,?,?), ctypes, ctypes).
index(is_endfile(?), ctypes, ctypes).
index(is_endline(?), ctypes, ctypes).
index(is_graph(?), ctypes, ctypes).
index(is_lower(?), ctypes, ctypes).
index(is_newline(?), ctypes, ctypes).
index(is_newpage(?), ctypes, ctypes).
index(is_paren(?,?), ctypes, ctypes).
index(is_period(?), ctypes, ctypes).
index(is_print(?), ctypes, ctypes).
index(is_punct(?), ctypes, ctypes).
index(is_quote(?), ctypes, ctypes).
index(is_space(?), ctypes, ctypes).
index(is_upper(?), ctypes, ctypes).
index(is_white(?), ctypes, ctypes).
index(to_lower(?,?), ctypes, ctypes).
index(to_upper(?,?), ctypes, ctypes).
index(upper_lower(?,?), ctypes, ctypes).
index(date_time_value(?,?,?), date, date).
index(parse_time(?,?), date, date).
index(parse_time(?,?,?), date, date).
index(day_of_the_week(?,?), date, date).
index(day_of_the_year(?,?), date, date).
index(debug(+,+,:), prolog_debug, debug).
index(debug(?), prolog_debug, debug).
index(nodebug(?), prolog_debug, debug).
index(debugging(?), prolog_debug, debug).
index(debugging(?,?), prolog_debug, debug).
index(list_debug_topics, prolog_debug, debug).
index(list_debug_topics(?), prolog_debug, debug).
index(debug_message_context(?), prolog_debug, debug).
index(assertion(0), prolog_debug, debug).
index(expects_dialect(?), prolog_dialect, dialect).
index(exists_source(?), prolog_dialect, dialect).
index(source_exports(?,?), prolog_dialect, dialect).
index(mapdict(2,+), dicts, dicts).
index(mapdict(3,?,?), dicts, dicts).
index(mapdict(4,?,?,?), dicts, dicts).
index(dicts_same_tag(?,?), dicts, dicts).
index(dict_size(?,?), dicts, dicts).
index(dict_keys(?,?), dicts, dicts).
index(dicts_same_keys(?,?), dicts, dicts).
index(dicts_to_same_keys(+,3,-), dicts, dicts).
index(dict_fill(?,?,?,?), dicts, dicts).
index(dict_no_fill(?,?,?), dicts, dicts).
index(dicts_join(?,?,?), dicts, dicts).
index(dicts_join(?,?,?,?), dicts, dicts).
index(dicts_slice(?,?,?), dicts, dicts).
index(dicts_to_compounds(?,+,3,?), dicts, dicts).
index(dif(?,?), dif, dif).
index(display(?), edinburgh, edinburgh).
index(display(?,?), edinburgh, edinburgh).
index(unknown(:,:), edinburgh, edinburgh).
index(reconsult(:), edinburgh, edinburgh).
index(debug, edinburgh, edinburgh).
index(nodebug, edinburgh, edinburgh).
index(fileerrors(?,?), edinburgh, edinburgh).
index(edit(?), prolog_edit, edit).
index(edit, prolog_edit, edit).
index(instantiation_error(?), error, error).
index(uninstantiation_error(?), error, error).
index(type_error(?,?), error, error).
index(domain_error(?,?), error, error).
index(existence_error(?,?), error, error).
index(existence_error(?,?,?), error, error).
index(permission_error(?,?,?), error, error).
index(representation_error(?), error, error).
index(resource_error(?), error, error).
index(syntax_error(?), error, error).
index(must_be(?,?), error, error).
index(is_of_type(?,?), error, error).
index(current_type(?,?,?), error, error).
index(catch(0,:,?,0), exceptions, exceptions).
index(exception(:,?), exceptions, exceptions).
index(exception_type(?,?), exceptions, exceptions).
index(explain(?), prolog_explain, explain).
index(explain(?,?), prolog_explain, explain).
index(fast_read(?), fastrw, fastrw).
index(fast_write(?), fastrw, fastrw).
index(fast_read(?,?), fastrw, fastrw).
index(fast_write(?,?), fastrw, fastrw).
index(fast_write_to_string(?,?,?), fastrw, fastrw).
index(can_open_file(?,?), files, files).
index(chdir(?), files, files).
index(reset_gensym, gensym, gensym).
index(reset_gensym(?), gensym, gensym).
index(gensym(?,?), gensym, gensym).
index(git(?,?), git, git).
index(git_process_output(+,1,+), git, git).
index(git_open_file(?,?,?,?), git, git).
index(is_git_directory(?), git, git).
index(git_describe(?,?), git, git).
index(git_hash(?,?), git, git).
index(git_ls_tree(?,?), git, git).
index(git_remote_url(?,?,?), git, git).
index(git_ls_remote(?,?,?), git, git).
index(git_branches(?,?), git, git).
index(git_remote_branches(?,?), git, git).
index(git_default_branch(?,?), git, git).
index(git_current_branch(?,?), git, git).
index(git_tags(?,?), git, git).
index(git_tags_on_branch(?,?,?), git, git).
index(git_shortlog(?,?,?), git, git).
index(git_log_data(?,?,?), git, git).
index(git_show(?,?,?,?), git, git).
index(git_commit_data(?,?,?), git, git).
index(is_git_hash(?), git, git).
index(ht_new(?), hashtable, hashtable).
index(ht_is_hashtable(?), hashtable, hashtable).
index(ht_size(?,?), hashtable, hashtable).
index(ht_put(?,?,?), hashtable, hashtable).
index(ht_update(?,?,?,?), hashtable, hashtable).
index(ht_put_new(?,?,?), hashtable, hashtable).
index(ht_put(?,?,?,?,?), hashtable, hashtable).
index(ht_del(?,?,?), hashtable, hashtable).
index(ht_get(?,?,?), hashtable, hashtable).
index(ht_gen(?,?,?), hashtable, hashtable).
index(ht_pairs(?,?), hashtable, hashtable).
index(ht_keys(?,?), hashtable, hashtable).
index(add_to_heap(?,?,?,?), heaps, heaps).
index(delete_from_heap(?,?,?,?), heaps, heaps).
index(empty_heap(?), heaps, heaps).
index(get_from_heap(?,?,?,?), heaps, heaps).
index(heap_size(?,?), heaps, heaps).
index(heap_to_list(?,?), heaps, heaps).
index(is_heap(?), heaps, heaps).
index(list_to_heap(?,?), heaps, heaps).
index(merge_heaps(?,?,?), heaps, heaps).
index(min_of_heap(?,?,?), heaps, heaps).
index(min_of_heap(?,?,?,?,?), heaps, heaps).
index(singleton_heap(?,?,?), heaps, heaps).
index(help, prolog_help, help).
index(help(?), prolog_help, help).
index(apropos(?), prolog_help, help).
index(help_text(?,?), prolog_help, help).
index(load_hotfixes(?), prolog_hotfix, hotfix).
index(incr_assert(:), increval, increval).
index(incr_asserta(:), increval, increval).
index(incr_assertz(:), increval, increval).
index(incr_retractall(:), increval, increval).
index(incr_retract(:), increval, increval).
index(is_incremental_subgoal(:), increval, increval).
index(incr_directly_depends(:,:), increval, increval).
index(incr_trans_depends(:,:), increval, increval).
index(incr_invalid_subgoals(?), increval, increval).
index(incr_is_invalid(:), increval, increval).
index(incr_invalidate_call(:), increval, increval).
index(incr_invalidate_calls(:), increval, increval).
index(incr_table_update, increval, increval).
index(incr_propagate_calls(:), increval, increval).
index(intercept(0,?,0), intercept, intercept).
index(intercept(0,?,1,?), intercept, intercept).
index(intercept_all(?,0,?,-), intercept, intercept).
index(nb_intercept_all(?,0,?,-), intercept, intercept).
index(send_signal(?), intercept, intercept).
index(send_silent_signal(?), intercept, intercept).
index(open_any(?,?,?,?,?), iostream, iostream).
index(close_any(?), iostream, iostream).
index(lazy_list(2,-), lazy_lists, lazy_lists).
index(lazy_list(3,+,-), lazy_lists, lazy_lists).
index(lazy_list_materialize(?), lazy_lists, lazy_lists).
index(lazy_list_length(?,?), lazy_lists, lazy_lists).
index(lazy_findall(?,0,-), lazy_lists, lazy_lists).
index(lazy_findall(+,?,0,-), lazy_lists, lazy_lists).
index(lazy_get_codes(?,?,?,?), lazy_lists, lazy_lists).
index(lazy_read_terms(?,?,?,?), lazy_lists, lazy_lists).
index(lazy_read_lines(?,?,?,?), lazy_lists, lazy_lists).
index(lazy_message_queue(?,?,?,?), lazy_lists, lazy_lists).
index(lazy_engine_next(?,?,?,?), lazy_lists, lazy_lists).
index(lazy_list_iterator(?,?,?,?), lazy_lists, lazy_lists).
index(listing, prolog_listing, listing).
index(listing(:), prolog_listing, listing).
index(listing(:,+), prolog_listing, listing).
index(portray_clause(?), prolog_listing, listing).
index(portray_clause(?,?), prolog_listing, listing).
index(portray_clause(+,+,:), prolog_listing, listing).
index(member(?,?), lists, lists).
index(memberchk(?,?), lists, lists).
index(append(?,?), lists, lists).
index(append(?,?,?), lists, lists).
index(prefix(?,?), lists, lists).
index(select(?,?,?), lists, lists).
index(selectchk(?,?,?), lists, lists).
index(select(?,?,?,?), lists, lists).
index(selectchk(?,?,?,?), lists, lists).
index(nextto(?,?,?), lists, lists).
index(delete(?,?,?), lists, lists).
index(nth0(?,?,?), lists, lists).
index(nth1(?,?,?), lists, lists).
index(nth0(?,?,?,?), lists, lists).
index(nth1(?,?,?,?), lists, lists).
index(last(?,?), lists, lists).
index(proper_length(?,?), lists, lists).
index(same_length(?,?), lists, lists).
index(reverse(?,?), lists, lists).
index(permutation(?,?), lists, lists).
index(flatten(?,?), lists, lists).
index(clumped(?,?), lists, lists).
index(subseq(?,?,?), lists, lists).
index(max_member(?,?), lists, lists).
index(min_member(?,?), lists, lists).
index(max_member(2,-,+), lists, lists).
index(min_member(2,-,+), lists, lists).
index(sum_list(?,?), lists, lists).
index(max_list(?,?), lists, lists).
index(min_list(?,?), lists, lists).
index(numlist(?,?,?), lists, lists).
index(is_set(?), lists, lists).
index(list_to_set(?,?), lists, lists).
index(intersection(?,?,?), lists, lists).
index(union(?,?,?), lists, lists).
index(subset(?,?), lists, lists).
index(subtract(?,?,?), lists, lists).
index(macro_position(?), macros, macros).
index(expand_macros(?,?,?,?,?), macros, macros).
index(include_macros(?,?,?), macros, macros).
index(:(op,op(10,fx,#)), macros, macros).
index(main, prolog_main, main).
index(argv_options(:,-,-), prolog_main, main).
index(argv_options(:,-,-,+), prolog_main, main).
index(argv_usage(:), prolog_main, main).
index(cli_parse_debug_options(?,?), prolog_main, main).
index(cli_debug_opt_type(?,?,?), prolog_main, main).
index(cli_debug_opt_help(?,?), prolog_main, main).
index(cli_debug_opt_meta(?,?), prolog_main, main).
index(cli_enable_development_system, prolog_main, main).
index(make, make, make).
index(make_reload_file(?), make, make).
index(in_temporary_module(?,0,0), modules, modules).
index(current_temporary_module(?), modules, modules).
index(nb_rb_insert(?,?,?), nb_rbtrees, nb_rbtrees).
index(nb_rb_get_node(?,?,?), nb_rbtrees, nb_rbtrees).
index(nb_rb_node_value(?,?), nb_rbtrees, nb_rbtrees).
index(nb_rb_set_node_value(?,?), nb_rbtrees, nb_rbtrees).
index(empty_nb_set(?), nb_set, nb_set).
index(add_nb_set(?,?), nb_set, nb_set).
index(add_nb_set(?,?,?), nb_set, nb_set).
index(size_nb_set(?,?), nb_set, nb_set).
index(nb_set_to_list(?,?), nb_set, nb_set).
index(gen_nb_set(?,?), nb_set, nb_set).
index(contains_term(?,?), occurs, occurs).
index(contains_var(?,?), occurs, occurs).
index(free_of_term(?,?), occurs, occurs).
index(free_of_var(?,?), occurs, occurs).
index(occurrences_of_term(?,?,?), occurs, occurs).
index(occurrences_of_var(?,?,?), occurs, occurs).
index(sub_term(?,?), occurs, occurs).
index(sub_var(?,?), occurs, occurs).
index(sub_term_shared_variables(?,?,?), occurs, occurs).
index(push_operators(:), prolog_operator, operators).
index(push_operators(:,-), prolog_operator, operators).
index(pop_operators, prolog_operator, operators).
index(pop_operators(?), prolog_operator, operators).
index(push_op(+,+,:), prolog_operator, operators).
index(option(?,?), swi_option, option).
index(option(?,?,?), swi_option, option).
index(select_option(?,?,?), swi_option, option).
index(select_option(?,?,?,?), swi_option, option).
index(merge_options(?,?,?), swi_option, option).
index(meta_options(1,:,-), swi_option, option).
index(dict_options(?,?), swi_option, option).
index(opt_parse(?,?,?,?,?), optparse, optparse).
index(opt_parse(?,?,?,?), optparse, optparse).
index(opt_arguments(?,?,?), optparse, optparse).
index(opt_help(?,?), optparse, optparse).
index(is_ordset(?), ordsets, ordsets).
index(list_to_ord_set(?,?), ordsets, ordsets).
index(ord_add_element(?,?,?), ordsets, ordsets).
index(ord_del_element(?,?,?), ordsets, ordsets).
index(ord_selectchk(?,?,?), ordsets, ordsets).
index(ord_intersect(?,?), ordsets, ordsets).
index(ord_intersect(?,?,?), ordsets, ordsets).
index(ord_intersection(?,?,?), ordsets, ordsets).
index(ord_intersection(?,?,?,?), ordsets, ordsets).
index(ord_disjoint(?,?), ordsets, ordsets).
index(ord_subtract(?,?,?), ordsets, ordsets).
index(ord_union(?,?), ordsets, ordsets).
index(ord_union(?,?,?), ordsets, ordsets).
index(ord_union(?,?,?,?), ordsets, ordsets).
index(ord_subset(?,?), ordsets, ordsets).
index(ord_empty(?), ordsets, ordsets).
index(ord_memberchk(?,?), ordsets, ordsets).
index(ord_symdiff(?,?,?), ordsets, ordsets).
index(ord_seteq(?,?), ordsets, ordsets).
index(ord_intersection(?,?), ordsets, ordsets).
index(oset_is(?), oset, oset).
index(oset_union(?,?,?), oset, oset).
index(oset_int(?,?,?), oset, oset).
index(oset_diff(?,?,?), oset, oset).
index(oset_dint(?,?), oset, oset).
index(oset_dunion(?,?), oset, oset).
index(oset_addel(?,?,?), oset, oset).
index(oset_delel(?,?,?), oset, oset).
index(oset_power(?,?), oset, oset).
index(pairs_keys_values(?,?,?), pairs, pairs).
index(pairs_values(?,?), pairs, pairs).
index(pairs_keys(?,?), pairs, pairs).
index(group_pairs_by_key(?,?), pairs, pairs).
index(transpose_pairs(?,?), pairs, pairs).
index(map_list_to_pairs(2,+,-), pairs, pairs).
index(persistent(?), persistency, persistency).
index(current_persistent_predicate(?), persistency, persistency).
index(db_attach(?,?), persistency, persistency).
index(db_detach, persistency, persistency).
index(db_attached(?), persistency, persistency).
index(db_sync(?), persistency, persistency).
index(db_sync_all(?), persistency, persistency).
index(:(op,op(1150,fx,persistent)), persistency, persistency).
index(portray_text(?), portray_text, portray_text).
index(set_portray_text(?,?), portray_text, portray_text).
index(set_portray_text(?,?,?), portray_text, portray_text).
index(print_term(?,?), prolog_pretty_print, pprint).
index(predicate_options(:,+,+), predicate_options, predicate_options).
index(assert_predicate_options(:,+,+,?), predicate_options, predicate_options).
index(current_option_arg(:,?), predicate_options, predicate_options).
index(current_predicate_option(:,?,?), predicate_options, predicate_options).
index(check_predicate_option(:,?,?), predicate_options, predicate_options).
index(current_predicate_options(:,?,?), predicate_options, predicate_options).
index(retractall_predicate_options, predicate_options, predicate_options).
index(derived_predicate_options(:,?,?), predicate_options, predicate_options).
index(derived_predicate_options(?), predicate_options, predicate_options).
index(check_predicate_options, predicate_options, predicate_options).
index(derive_predicate_options, predicate_options, predicate_options).
index(check_predicate_options(:), predicate_options, predicate_options).
index(autoload_all, prolog_autoload, prolog_autoload).
index(autoload_all(?), prolog_autoload, prolog_autoload).
index(set_breakpoint(?,?,?,?), prolog_breakpoints, prolog_breakpoints).
index(set_breakpoint(?,?,?,?,?), prolog_breakpoints, prolog_breakpoints).
index(set_breakpoint_condition(?,?), prolog_breakpoints, prolog_breakpoints).
index(delete_breakpoint(?), prolog_breakpoints, prolog_breakpoints).
index(breakpoint_property(?,?), prolog_breakpoints, prolog_breakpoints).
index(clause_info(?,?,?,?), prolog_clause, prolog_clause).
index(clause_info(?,?,?,?,?), prolog_clause, prolog_clause).
index(initialization_layout(?,?,?,?), prolog_clause, prolog_clause).
index(predicate_name(?,?), prolog_clause, prolog_clause).
index(clause_name(?,?), prolog_clause, prolog_clause).
index(:(public,unify_term(_,_)), prolog_clause, prolog_clause).
index(:(public,make_varnames(_,_,_,_,_)), prolog_clause, prolog_clause).
index(:(public,do_make_varnames(_,_,_)), prolog_clause, prolog_clause).
index(comma_list(?,?), prolog_code, prolog_code).
index(semicolon_list(?,?), prolog_code, prolog_code).
index(mkconj(?,?,?), prolog_code, prolog_code).
index(mkdisj(?,?,?), prolog_code, prolog_code).
index(pi_head(?,?), prolog_code, prolog_code).
index(head_name_arity(?,?,?), prolog_code, prolog_code).
index(most_general_goal(?,?), prolog_code, prolog_code).
index(extend_goal(?,?,?), prolog_code, prolog_code).
index(predicate_label(?,?), prolog_code, prolog_code).
index(predicate_sort_key(?,?), prolog_code, prolog_code).
index(is_control_goal(?), prolog_code, prolog_code).
index(is_predicate_indicator(?), prolog_code, prolog_code).
index(body_term_calls(:,-), prolog_code, prolog_code).
index(prolog_walk_code(:), prolog_codewalk, prolog_codewalk).
index(prolog_program_clause(?,?), prolog_codewalk, prolog_codewalk).
index(prolog_colourise_stream(+,+,3), prolog_colour, prolog_colour).
index(prolog_colourise_stream(+,+,3,+), prolog_colour, prolog_colour).
index(prolog_colourise_term(+,+,3,+), prolog_colour, prolog_colour).
index(prolog_colourise_query(+,+,3), prolog_colour, prolog_colour).
index(syntax_colour(?,?), prolog_colour, prolog_colour).
index(syntax_message(?,?,?), prolog_colour, prolog_colour).
index(prolog_dump_runtime_variables, prolog_config, prolog_config).
index(prolog_config(?,?), prolog_config, prolog_config).
index(coverage(0), prolog_coverage, prolog_coverage).
index(coverage(0,+), prolog_coverage, prolog_coverage).
index(show_coverage(:), prolog_coverage, prolog_coverage).
index(show_coverage(0,+), prolog_coverage, prolog_coverage).
index(cov_save_data(?,?), prolog_coverage, prolog_coverage).
index(cov_load_data(?,?), prolog_coverage, prolog_coverage).
index(cov_reset, prolog_coverage, prolog_coverage).
index(cov_property(?), prolog_coverage, prolog_coverage).
index(spy(:), prolog_debug_tools, prolog_debug).
index(nospy(:), prolog_debug_tools, prolog_debug).
index(nospyall, prolog_debug_tools, prolog_debug).
index(debugging, prolog_debug_tools, prolog_debug).
index(trap(?), prolog_debug_tools, prolog_debug).
index(notrap(?), prolog_debug_tools, prolog_debug).
index(file_autoload_directives(?,?,?), prolog_deps, prolog_deps).
index(file_auto_import(?,?), prolog_deps, prolog_deps).
index(evaluable_property(?,?), prolog_evaluable, prolog_evaluable).
index(format_spec(?,?), prolog_format, prolog_format).
index(format_spec(?,?,?), prolog_format, prolog_format).
index(format_types(?,?), prolog_format, prolog_format).
index(prolog_history(?), prolog_history, prolog_history).
index(jiti_list, prolog_jiti, prolog_jiti).
index(jiti_list(:), prolog_jiti, prolog_jiti).
index(jiti_suggest_modes(:), prolog_jiti, prolog_jiti).
index(jiti_suggest_modes, prolog_jiti, prolog_jiti).
index(setup_prolog_integer_grouping, prolog_locale, prolog_locale).
index(infer_meta_predicate(:,-), prolog_metainference, prolog_metainference).
index(inferred_meta_predicate(:,?), prolog_metainference, prolog_metainference).
index(pack_list_installed, prolog_pack, prolog_pack).
index(pack_info(?), prolog_pack, prolog_pack).
index(pack_list(?), prolog_pack, prolog_pack).
index(pack_list(?,?), prolog_pack, prolog_pack).
index(pack_search(?), prolog_pack, prolog_pack).
index(pack_install(?), prolog_pack, prolog_pack).
index(pack_install(?,?), prolog_pack, prolog_pack).
index(pack_install_local(2,+,+), prolog_pack, prolog_pack).
index(pack_upgrade(?), prolog_pack, prolog_pack).
index(pack_rebuild(?), prolog_pack, prolog_pack).
index(pack_rebuild, prolog_pack, prolog_pack).
index(pack_remove(?), prolog_pack, prolog_pack).
index(pack_remove(?,?), prolog_pack, prolog_pack).
index(pack_publish(?,?), prolog_pack, prolog_pack).
index(pack_property(?,?), prolog_pack, prolog_pack).
index(profile(0), prolog_profile, prolog_profile).
index(profile(0,+), prolog_profile, prolog_profile).
index(show_profile(?), prolog_profile, prolog_profile).
index(profile_data(?), prolog_profile, prolog_profile).
index(profile_procedure_data(:,-), prolog_profile, prolog_profile).
index(qlf_make, prolog_qlfmake, prolog_qlfmake).
index(qlf_make(?), prolog_qlfmake, prolog_qlfmake).
index(prolog_read_source_term(?,?,?,?), prolog_source, prolog_source).
index(read_source_term_at_location(?,?,?), prolog_source, prolog_source).
index(prolog_file_directives(?,?,?), prolog_source, prolog_source).
index(prolog_open_source(?,?), prolog_source, prolog_source).
index(prolog_close_source(?), prolog_source, prolog_source).
index(prolog_canonical_source(?,?), prolog_source, prolog_source).
index(load_quasi_quotation_syntax(?,?), prolog_source, prolog_source).
index(file_name_on_path(?,?), prolog_source, prolog_source).
index(file_alias_path(?,?), prolog_source, prolog_source).
index(path_segments_atom(?,?), prolog_source, prolog_source).
index(directory_source_files(?,?,?), prolog_source, prolog_source).
index(valid_term_position(?,?), prolog_source, prolog_source).
index(get_prolog_backtrace(?,?), prolog_stack, prolog_stack).
index(get_prolog_backtrace(?,?,?), prolog_stack, prolog_stack).
index(prolog_stack_frame_property(?,?), prolog_stack, prolog_stack).
index(print_prolog_backtrace(?,?), prolog_stack, prolog_stack).
index(print_prolog_backtrace(?,?,?), prolog_stack, prolog_stack).
index(backtrace(?), prolog_stack, prolog_stack).
index(print_last_choicepoint, prolog_stack, prolog_stack).
index(print_last_choicepoint(?,?), prolog_stack, prolog_stack).
index(trace(:), prolog_trace, prolog_trace).
index(trace(:,+), prolog_trace, prolog_trace).
index(tracing(:,-), prolog_trace, prolog_trace).
index(list_tracing, prolog_trace, prolog_trace).
index(notraceall, prolog_trace, prolog_trace).
index(require_prolog_version(?,?), prolog_versions, prolog_versions).
index(require_version(?,?,?), prolog_versions, prolog_versions).
index(cmp_versions(?,?,?), prolog_versions, prolog_versions).
index(wrap_predicate(:,+,-,0), prolog_wrap, prolog_wrap).
index(unwrap_predicate(?,?), prolog_wrap, prolog_wrap).
index(current_predicate_wrapper(:,-,-,-), prolog_wrap, prolog_wrap).
index(xref_source(?), prolog_xref, prolog_xref).
index(xref_source(?,?), prolog_xref, prolog_xref).
index(xref_called(?,?,?), prolog_xref, prolog_xref).
index(xref_called(?,?,?,?), prolog_xref, prolog_xref).
index(xref_called(?,?,?,?,?), prolog_xref, prolog_xref).
index(xref_defined(?,?,?), prolog_xref, prolog_xref).
index(xref_definition_line(?,?), prolog_xref, prolog_xref).
index(xref_exported(?,?), prolog_xref, prolog_xref).
index(xref_module(?,?), prolog_xref, prolog_xref).
index(xref_uses_file(?,?,?), prolog_xref, prolog_xref).
index(xref_op(?,?), prolog_xref, prolog_xref).
index(xref_prolog_flag(?,?,?,?), prolog_xref, prolog_xref).
index(xref_comment(?,?,?), prolog_xref, prolog_xref).
index(xref_comment(?,?,?,?), prolog_xref, prolog_xref).
index(xref_mode(?,?,?), prolog_xref, prolog_xref).
index(xref_option(?,?), prolog_xref, prolog_xref).
index(xref_clean(?), prolog_xref, prolog_xref).
index(xref_current_source(?), prolog_xref, prolog_xref).
index(xref_done(?,?), prolog_xref, prolog_xref).
index(xref_built_in(?), prolog_xref, prolog_xref).
index(xref_source_file(?,?,?), prolog_xref, prolog_xref).
index(xref_source_file(?,?,?,?), prolog_xref, prolog_xref).
index(xref_public_list(?,?,?), prolog_xref, prolog_xref).
index(xref_public_list(?,?,?,?), prolog_xref, prolog_xref).
index(xref_public_list(?,?,?,?,?,?), prolog_xref, prolog_xref).
index(xref_public_list(?,?,?,?,?,?,?), prolog_xref, prolog_xref).
index(xref_meta(?,?,?), prolog_xref, prolog_xref).
index(xref_meta(?,?), prolog_xref, prolog_xref).
index(xref_hook(?), prolog_xref, prolog_xref).
index(xref_used_class(?,?), prolog_xref, prolog_xref).
index(xref_defined_class(?,?,?), prolog_xref, prolog_xref).
index(phrase_from_file(?,?), pure_input, pure_input).
index(phrase_from_file(?,?,?), pure_input, pure_input).
index(phrase_from_stream(?,?), pure_input, pure_input).
index(stream_to_lazy_list(?,?), pure_input, pure_input).
index(syntax_error(?,?,?), pure_input, pure_input).
index(lazy_list_location(?,?,?), pure_input, pure_input).
index(lazy_list_character_count(?,?,?), pure_input, pure_input).
index(load_foreign_files, qp_foreign, qpforeign).
index(load_foreign_files(:,+), qp_foreign, qpforeign).
index(load_foreign_files(+,:,+), qp_foreign, qpforeign).
index(make_shared_object(+,:,+), qp_foreign, qpforeign).
index(make_foreign_wrapper_file(:), qp_foreign, qpforeign).
index(make_foreign_wrapper_file(:,+), qp_foreign, qpforeign).
index(make_foreign_resource_wrapper(:,+,+), qp_foreign, qpforeign).
index(load_foreign_resource(:,+), qp_foreign, qpforeign).
index(qsave_program(?), qsave, qsave).
index(qsave_program(+,:), qsave, qsave).
index(with_quasi_quotation_input(+,-,0), quasi_quotations, quasi_quotations).
index(phrase_from_quasi_quotation(//,+), quasi_quotations, quasi_quotations).
index(quasi_quotation_syntax_error(?), quasi_quotations, quasi_quotations).
index(quasi_quotation_syntax(4), quasi_quotations, quasi_quotations).
index(unix(?), quintus, quintus).
index(abs(?,?), quintus, quintus).
index(sin(?,?), quintus, quintus).
index(cos(?,?), quintus, quintus).
index(tan(?,?), quintus, quintus).
index(log(?,?), quintus, quintus).
index(log10(?,?), quintus, quintus).
index(pow(?,?,?), quintus, quintus).
index(ceiling(?,?), quintus, quintus).
index(floor(?,?), quintus, quintus).
index(round(?,?), quintus, quintus).
index(acos(?,?), quintus, quintus).
index(asin(?,?), quintus, quintus).
index(atan(?,?), quintus, quintus).
index(atan2(?,?,?), quintus, quintus).
index(sign(?,?), quintus, quintus).
index(sqrt(?,?), quintus, quintus).
index(genarg(?,?,?), quintus, quintus).
index(no_style_check(?), quintus, quintus).
index(otherwise, quintus, quintus).
index(simple(?), quintus, quintus).
index(prolog_flag(?,?), quintus, quintus).
index(date(?), quintus, quintus).
index(current_stream(?,?,?), quintus, quintus).
index(stream_position(?,?,?), quintus, quintus).
index(skip_line, quintus, quintus).
index(skip_line(?), quintus, quintus).
index(compile(?), quintus, quintus).
index(atom_char(?,?), quintus, quintus).
index(midstring(?,?,?), quintus, quintus).
index(midstring(?,?,?,?), quintus, quintus).
index(midstring(?,?,?,?,?), quintus, quintus).
index(midstring(?,?,?,?,?,?), quintus, quintus).
index(raise_exception(?), quintus, quintus).
index(on_exception(?,?,?), quintus, quintus).
index(random(?), random, random).
index(random_between(?,?,?), random, random).
index(getrand(?), random, random).
index(setrand(?), random, random).
index(maybe, random, random).
index(maybe(?), random, random).
index(maybe(?,?), random, random).
index(random_perm2(?,?,?,?), random, random).
index(random_member(?,?), random, random).
index(random_select(?,?,?), random, random).
index(random_subseq(?,?,?), random, random).
index(randseq(?,?,?), random, random).
index(randset(?,?,?), random, random).
index(random_permutation(?,?), random, random).
index(random_numlist(?,?,?,?), random, random).
index(random(?,?,?), random, random).
index(rb_new(?), rbtrees, rbtrees).
index(rb_empty(?), rbtrees, rbtrees).
index(rb_lookup(?,?,?), rbtrees, rbtrees).
index(rb_update(?,?,?,?), rbtrees, rbtrees).
index(rb_update(?,?,?,?,?), rbtrees, rbtrees).
index(rb_apply(+,+,2,-), rbtrees, rbtrees).
index(rb_insert(?,?,?,?), rbtrees, rbtrees).
index(rb_insert_new(?,?,?,?), rbtrees, rbtrees).
index(rb_delete(?,?,?), rbtrees, rbtrees).
index(rb_delete(?,?,?,?), rbtrees, rbtrees).
index(rb_visit(?,?), rbtrees, rbtrees).
index(rb_keys(?,?), rbtrees, rbtrees).
index(rb_map(?,1), rbtrees, rbtrees).
index(rb_map(+,2,-), rbtrees, rbtrees).
index(rb_partial_map(+,+,2,-), rbtrees, rbtrees).
index(rb_fold(3,+,+,-), rbtrees, rbtrees).
index(rb_clone(?,?,?), rbtrees, rbtrees).
index(rb_min(?,?,?), rbtrees, rbtrees).
index(rb_max(?,?,?), rbtrees, rbtrees).
index(rb_del_min(?,?,?,?), rbtrees, rbtrees).
index(rb_del_max(?,?,?,?), rbtrees, rbtrees).
index(rb_next(?,?,?,?), rbtrees, rbtrees).
index(rb_previous(?,?,?,?), rbtrees, rbtrees).
index(list_to_rbtree(?,?), rbtrees, rbtrees).
index(ord_list_to_rbtree(?,?), rbtrees, rbtrees).
index(is_rbtree(?), rbtrees, rbtrees).
index(rb_size(?,?), rbtrees, rbtrees).
index(rb_in(?,?,?), rbtrees, rbtrees).
index(readln(?), readln, readln).
index(readln(?,?), readln, readln).
index(readln(?,?,?,?,?), readln, readln).
index(read_line_to_codes(?,?), read_util, readutil).
index(read_line_to_codes(?,?,?), read_util, readutil).
index(read_stream_to_codes(?,?), read_util, readutil).
index(read_stream_to_codes(?,?,?), read_util, readutil).
index(read_file_to_codes(?,?,?), read_util, readutil).
index(read_line_to_string(?,?), read_util, readutil).
index(read_file_to_string(?,?,?), read_util, readutil).
index(read_file_to_terms(?,?,?), read_util, readutil).
index(record(?), record, record).
index(current_record(?,?), record, record).
index(current_record_predicate(?,?), record, record).
index(:(op,op(1150,fx,record)), record, record).
index(with_rwlock(+,0,+), rwlocks, rwlocks).
index(with_rwlock(+,0,+,+), rwlocks, rwlocks).
index(safe_goal(:), sandbox, sandbox).
index(safe_call(0), sandbox, sandbox).
index(setting(:,+,+,+), settings, settings).
index(setting(:,?), settings, settings).
index(set_setting(:,+), settings, settings).
index(set_setting_default(:,+), settings, settings).
index(restore_setting(:), settings, settings).
index(load_settings(?), settings, settings).
index(load_settings(?,?), settings, settings).
index(save_settings, settings, settings).
index(save_settings(?), settings, settings).
index(current_setting(:), settings, settings).
index(setting_property(?,?), settings, settings).
index(list_settings, settings, settings).
index(list_settings(?), settings, settings).
index(convert_setting_text(?,?,?), settings, settings).
index(shell, shell, shell).
index(ls, shell, shell).
index(ls(?), shell, shell).
index(cd, shell, shell).
index(cd(?), shell, shell).
index(pushd, shell, shell).
index(pushd(?), shell, shell).
index(dirs, shell, shell).
index(pwd, shell, shell).
index(popd, shell, shell).
index(mv(?,?), shell, shell).
index(rm(?), shell, shell).
index(load_foreign_library(:), shlib, shlib).
index(load_foreign_library(:,+), shlib, shlib).
index(unload_foreign_library(?), shlib, shlib).
index(unload_foreign_library(?,?), shlib, shlib).
index(current_foreign_library(?,?), shlib, shlib).
index(reload_foreign_libraries, shlib, shlib).
index(use_foreign_library(?), shlib, shlib).
index(use_foreign_library(?,?), shlib, shlib).
index(distinct(0), solution_sequences, solution_sequences).
index(distinct(?,0), solution_sequences, solution_sequences).
index(reduced(0), solution_sequences, solution_sequences).
index(reduced(?,0,+), solution_sequences, solution_sequences).
index(limit(+,0), solution_sequences, solution_sequences).
index(offset(+,0), solution_sequences, solution_sequences).
index(call_nth(0,?), solution_sequences, solution_sequences).
index(order_by(+,0), solution_sequences, solution_sequences).
index(group_by(?,?,0,-), solution_sequences, solution_sequences).
index(predsort(3,+,-), sort, sort).
index(locale_sort(?,?), sort, sort).
index(statistics, prolog_statistics, statistics).
index(statistics(?), prolog_statistics, statistics).
index(thread_statistics(?,?), prolog_statistics, statistics).
index(time(0), prolog_statistics, statistics).
index(call_time(0,-), prolog_statistics, statistics).
index(call_time(0,-,-), prolog_statistics, statistics).
index(with_output_to(?,0,+), streams, streams).
index(dedent_lines(?,?,?), strings, strings).
index(indent_lines(?,?,?), strings, strings).
index(indent_lines(1,+,+,-), strings, strings).
index(interpolate_string(:,-,+,+), strings, strings).
index(string_lines(?,?), strings, strings).
index(string(?,?,?,?), strings, strings).
index(lock_predicate(?), swi_system_utilities, system).
index(unlock_predicate(?), swi_system_utilities, system).
index(system_mode(?), swi_system_utilities, system).
index(system_module, swi_system_utilities, system).
index(abolish_all_tables, tables, tables).
index(abolish_module_tables(?), tables, tables).
index(abolish_table_pred(:), tables, tables).
index(abolish_table_call(:), tables, tables).
index(abolish_table_call(:,+), tables, tables).
index(abolish_table_subgoals(:,+), tables, tables).
index(tfindall(+,0,-), tables, tables).
index('t not'(0), tables, tables).
index(get_call(:,-,-), tables, tables).
index(get_calls(:,-,-), tables, tables).
index(get_returns(?,?), tables, tables).
index(get_returns(?,?,?), tables, tables).
index(get_returns_and_dls(+,-,:), tables, tables).
index(get_returns_and_tvs(?,?,?), tables, tables).
index(get_returns_for_call(:,:), tables, tables).
index(get_residual(:,-), tables, tables).
index(set_pil_on, tables, tables).
index(set_pil_off, tables, tables).
index(:(op,op(900,fy,tnot)), tables, tables).
index(term_hash(?,?), terms, terms).
index(term_hash(?,?,?,?), terms, terms).
index(term_size(?,?), terms, terms).
index(term_variables(?,?), terms, terms).
index(term_variables(?,?,?), terms, terms).
index(variant(?,?), terms, terms).
index(subsumes(?,?), terms, terms).
index(subsumes_chk(?,?), terms, terms).
index(cyclic_term(?), terms, terms).
index(acyclic_term(?), terms, terms).
index(term_subsumer(?,?,?), terms, terms).
index(term_factorized(?,?,?), terms, terms).
index(mapargs(2,?,?), terms, terms).
index(mapsubterms(2,?,?), terms, terms).
index(mapsubterms_var(2,?,?), terms, terms).
index(foldsubterms(3,+,+,-), terms, terms).
index(foldsubterms(4,+,?,+,-), terms, terms).
index(same_functor(?,?), terms, terms).
index(same_functor(?,?,?), terms, terms).
index(same_functor(?,?,?,?), terms, terms).
index(concurrent(+,:,+), thread, thread).
index(concurrent_maplist(1,+), thread, thread).
index(concurrent_maplist(2,?,?), thread, thread).
index(concurrent_maplist(3,?,?,?), thread, thread).
index(concurrent_forall(0,0), thread, thread).
index(concurrent_forall(0,0,+), thread, thread).
index(concurrent_and(0,0), thread, thread).
index(concurrent_and(0,0,+), thread, thread).
index(first_solution(-,:,+), thread, thread).
index(call_in_thread(+,0), thread, thread).
index(thread_pool_create(?,?,?), thread_pool, thread_pool).
index(thread_pool_destroy(?), thread_pool, thread_pool).
index(thread_create_in_pool(+,0,-,:), thread_pool, thread_pool).
index(current_thread_pool(?), thread_pool, thread_pool).
index(thread_pool_property(?,?), thread_pool, thread_pool).
index(threads, thread_util, threadutil).
index(join_threads, thread_util, threadutil).
index(with_stopped_threads(0,+), thread_util, threadutil).
index(thread_has_console, thread_util, threadutil).
index(attach_console, thread_util, threadutil).
index(attach_console(?), thread_util, threadutil).
index(tspy(?), thread_util, threadutil).
index(tspy(?,?), thread_util, threadutil).
index(tdebug, thread_util, threadutil).
index(tdebug(?), thread_util, threadutil).
index(tnodebug, thread_util, threadutil).
index(tnodebug(?), thread_util, threadutil).
index(tprofile(?), thread_util, threadutil).
index(tbacktrace(?), thread_util, threadutil).
index(tbacktrace(?,?), thread_util, threadutil).
index(interactor, thread_util, threadutil).
index(interactor(?), thread_util, threadutil).
index(tty_clear, tty, tty).
index(tty_flash, tty, tty).
index(menu(?,?,?), tty, tty).
index(add_edges(?,?,?), ugraphs, ugraphs).
index(add_vertices(?,?,?), ugraphs, ugraphs).
index(complement(?,?), ugraphs, ugraphs).
index(compose(?,?,?), ugraphs, ugraphs).
index(del_edges(?,?,?), ugraphs, ugraphs).
index(del_vertices(?,?,?), ugraphs, ugraphs).
index(edges(?,?), ugraphs, ugraphs).
index(neighbors(?,?,?), ugraphs, ugraphs).
index(neighbours(?,?,?), ugraphs, ugraphs).
index(reachable(?,?,?), ugraphs, ugraphs).
index(top_sort(?,?), ugraphs, ugraphs).
index(ugraph_layers(?,?), ugraphs, ugraphs).
index(transitive_closure(?,?), ugraphs, ugraphs).
index(transpose_ugraph(?,?), ugraphs, ugraphs).
index(vertices(?,?), ugraphs, ugraphs).
index(vertices_edges_to_ugraph(?,?,?), ugraphs, ugraphs).
index(ugraph_union(?,?,?), ugraphs, ugraphs).
index(connect_ugraph(?,?,?), ugraphs, ugraphs).
index(parse_url(?,?), url, url).
index(parse_url(?,?,?), url, url).
index(is_absolute_url(?), url, url).
index(global_url(?,?,?), url, url).
index(http_location(?,?), url, url).
index(www_form_encode(?,?), url, url).
index(parse_url_search(?,?), url, url).
index(url_iri(?,?), url, url).
index(file_name_to_url(?,?), url, url).
index(set_url_encoding(?,?), url, url).
index(utf8_codes(?,?,?), utf8, utf8).
index(numbervars(?), varnumbers, varnumbers).
index(varnumbers(?,?), varnumbers, varnumbers).
index(max_var_number(?,?,?), varnumbers, varnumbers).
index(varnumbers(?,?,?), varnumbers, varnumbers).
index(varnumbers_names(?,?,?), varnumbers, varnumbers).
index(vm_list(:), prolog_vm, vm).
index(clause_vm(?,?), prolog_vm, vm).
index(vmi_labels(?,?), prolog_vm, vm).
index(call_residual_program(0,:), wfs, wfs).
index(call_delays(0,:), wfs, wfs).
index(delays_residual_program(:,:), wfs, wfs).
index(answer_residual(:,:), wfs, wfs).
index(:(op,op(900,fy,tnot)), wfs, wfs).
index(when(+,0), when, when).
index(writef(?), writef, writef).
index(writef(?,?), writef, writef).
index(swritef(?,?), writef, writef).
index(swritef(?,?,?), writef, writef).
index(www_open_url(?), www_browser, www_browser).
index(expand_url_path(?,?), www_browser, www_browser).
index(>>(?,0), yall, yall).
index(>>(?,:,?), yall, yall).
index(>>(?,:,?,?), yall, yall).
index(>>(?,:,?,?,?), yall, yall).
index(>>(?,:,?,?,?,?), yall, yall).
index(>>(?,:,?,?,?,?,?), yall, yall).
index(>>(?,:,?,?,?,?,?,?), yall, yall).
index(>>(?,:,?,?,?,?,?,?,?), yall, yall).
index(/(?,?), yall, yall).
index(/(?,?,?), yall, yall).
index(/(?,?,?,?), yall, yall).
index(/(?,?,?,?,?), yall, yall).
index(/(?,?,?,?,?,?), yall, yall).
index(/(?,?,?,?,?,?,?), yall, yall).
index(/(?,?,?,?,?,?,?,?), yall, yall).
index(/(?,?,?,?,?,?,?,?,?), yall, yall).
index(lambda_calls(?,?), yall, yall).
index(lambda_calls(?,?,?), yall, yall).
index(is_lambda(?), yall, yall).
index(zip_open(?,?,?,?), zip, zip).
index(zip_close(?), zip, zip).
index(zip_close(?,?), zip, zip).
index(with_zipper(+,0), zip, zip).
index(zipper_open_new_file_in_zip(?,?,?,?), zip, zip).
index(zipper_goto(?,?), zip, zip).
index(zipper_open_current(?,?,?), zip, zip).
index(zipper_members(?,?), zip, zip).
index(zipper_file_info(?,?,?), zip, zip).
